<?php
/**
 * About Us Message Template options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

// Add panel for section options
$wp_customize->add_panel( 'corporate_education_pro_about_us_panel' , array(
    'title'      => esc_html__( 'About Us Template','corporate-education-pro' ),
    'description'=> esc_html__( 'About Us Template Options', 'corporate-education-pro' ),
    'priority'   => 150,
) );

/*
 * Image Section
 */
$wp_customize->add_section( 'corporate_education_pro_about_image_section', array(
	'title'             => esc_html__( 'Featured Image Section','corporate-education-pro' ),
	'description'       => esc_html__( 'Image Section Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_about_us_panel',
) );

// image Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_image_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['about_image_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_image_enable]', array(
	'label'            	=> esc_html__( 'Enable Image Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about_image_section',
	'type'             	=> 'checkbox',
) );

for( $i = 1; $i <= 3; $i++ ) {
	// image Section background setting and control.
	$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_image_' . $i . ']', array(
		'sanitize_callback' => 'corporate_education_pro_sanitize_image'
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'corporate_education_pro_theme_options[about_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Select Image %d', 'corporate-education-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'corporate-education-pro' ), 400, 270 ),
			'section'     		=> 'corporate_education_pro_about_image_section',
			'active_callback'	=> 'corporate_education_pro_is_about_image_enable',
	) ) );
}

/*
 * Message Section
 */
$wp_customize->add_section( 'corporate_education_pro_message_section', array(
	'title'             => esc_html__( 'Message From Chairman','corporate-education-pro' ),
	'description'       => esc_html__( 'Message From Chairman Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_about_us_panel',
) );

// main service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[message_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['message_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[message_enable]', array(
	'label'            	=> esc_html__( 'Enable Message Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_message_section',
	'type'             	=> 'checkbox',
) );

// Message Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[message_content_type]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
	'default'			=> $options['message_content_type'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[message_content_type]', array(
	'label'            	=> esc_html__( 'Message Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_message_section',
	'type'             	=> 'select',
	'choices'			=> corporate_education_pro_message(),
	'active_callback'	=> 'corporate_education_pro_is_message_enable',
) );

// Message Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[message_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['message_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[message_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_message_section',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_message_content_custom',
) );

// Message Section sub title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[message_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['message_sub_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[message_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_message_section',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_message_enable',
) );

// Message Section description setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[message_description]', array(
	'sanitize_callback'	=> 'wp_kses_post',
	'default'          	=> $options['message_description'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[message_description]', array(
	'label'            	=> esc_html__( 'Description', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_message_section',
	'type'             	=> 'textarea',
	'active_callback'	=> 'corporate_education_pro_message_content_custom',
) );

// Message Section description setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[message_link]', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'          	=> $options['message_link'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[message_link]', array(
	'label'            	=> esc_html__( 'Link URL', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_message_section',
	'type'             	=> 'url',
	'active_callback'	=> 'corporate_education_pro_message_content_custom',
) );

// message Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[message_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[message_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_message_content_post',
	'label'             => esc_html__( 'Input Post ID', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post ID', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_message_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[message_content_page]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_page',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[message_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'corporate-education-pro' ),
	'section'        	=> 'corporate_education_pro_message_section',
	'active_callback' 	=> 'corporate_education_pro_message_content_page',
	'type'				=> 'dropdown-pages'
) );


/**
 * About Us Features Template options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

/*
 * Features Section
 */
$wp_customize->add_section( 'corporate_education_pro_features_section', array(
	'title'             => esc_html__( 'Features','corporate-education-pro' ),
	'description'       => esc_html__( 'Features Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_about_us_panel',
) );

// main service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[features_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['features_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[features_enable]', array(
	'label'            	=> esc_html__( 'Enable Features Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_features_section',
	'type'             	=> 'checkbox',
) );

// Features Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[features_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['features_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[features_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_features_section',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_features_enable',
) );

// Features Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[features_description]', array(
	'sanitize_callback'	=> 'wp_kses_post',
	'default'          	=> $options['features_description'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[features_description]', array(
	'label'            	=> esc_html__( 'Description', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_features_section',
	'type'             	=> 'textarea',
	'active_callback'	=> 'corporate_education_pro_is_features_enable',
) );

// Features Section content type setting and control.
// options are same as goal section's
$wp_customize->add_setting( 'corporate_education_pro_theme_options[features_content_type]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
	'default'			=> $options['features_content_type'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[features_content_type]', array(
	'label'            	=> esc_html__( 'Features Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_features_section',
	'type'             	=> 'select',
	'choices'			=> corporate_education_pro_goal(),
	'active_callback'	=> 'corporate_education_pro_is_features_enable',
) );

// Features Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[features_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[features_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_features_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please input 4 post ids. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_features_section',
	'type'				=> 'text',
) );

// Features Section page setting and control
for ( $i = 1; $i <= 4; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'corporate_education_pro_theme_options[features_content_page_'.$i.']', array(
		'sanitize_callback' => 'corporate_education_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'corporate_education_pro_theme_options[features_content_page_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'corporate-education-pro' ), $i ),
		'section'        	=> 'corporate_education_pro_features_section',
		'active_callback' 	=> 'corporate_education_pro_features_content_page',
		'type'				=> 'dropdown-pages'
	) );
}

/**
 * About Us Team options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

/*
 * team Section
 */
$wp_customize->add_section( 'corporate_education_pro_about_team', array(
	'title'             => esc_html__( 'Team','corporate-education-pro' ),
	'description'       => esc_html__( 'Team Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_about_us_panel',
) );

// about team Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_team_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['about_team_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_team_enable]', array(
	'label'            	=> esc_html__( 'Enable Team Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about_team',
	'type'             	=> 'checkbox',
) );

// about team Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_team_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['about_team_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_team_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about_team',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_about_team_enable',
) );

// about team Section sub title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_team_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['about_team_sub_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_team_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about_team',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_about_team_enable',
) );

// about team Section description setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_team_description]', array(
	'sanitize_callback'	=> 'wp_kses_post',
	'default'          	=> $options['about_team_description'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_team_description]', array(
	'label'            	=> esc_html__( 'Description', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about_team',
	'type'             	=> 'textarea',
	'active_callback'	=> 'corporate_education_pro_is_about_team_enable',
) );

// about team Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_team_content_type]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
	'default'			=> $options['about_team_content_type'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_team_content_type]', array(
	'label'            	=> esc_html__( 'Team Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about_team',
	'type'             	=> 'select',
	'choices'			=> corporate_education_pro_about_team_content_type(),
	'active_callback'	=> 'corporate_education_pro_is_about_team_enable',
) );

// about team Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_team_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_team_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_about_team_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please input 5 post ids. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_about_team',
	'type'				=> 'text',
) );

// about team Section content type team setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_team_content_team]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_team_content_team]', array(
	'active_callback'	=> 'corporate_education_pro_about_team_content_team',
	'label'             => esc_html__( 'Input Team Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please input 5 team ids. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_about_team',
	'type'				=> 'text',
) );

// about team Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_team_content_category]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[about_team_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Latest five posts from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_about_team',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_about_team_content_category',
) ) );

// about team Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_team_content_team_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[about_team_content_team_category]', array(
	'label'           => esc_html__( 'Select Team Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Latest five teams from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_about_team',
	'taxonomy'		  => 'tp-team-category',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_about_team_content_team_category',
) ) );