<?php 
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_counter_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if counter is enabled
        $enable_counter = apply_filters( 'corporate_education_pro_section_status', true, 'counter_enable' );

        if ( true !== $enable_counter ) {
            return false;
        }

        // Render counter section now.
        corporate_education_pro_render_counter_section();
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_counter_section', 80 );

if ( ! function_exists( 'corporate_education_pro_render_counter_section' ) ) :
    /**
    * Start counter section
    *
    * @return string counter content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_counter_section() {
        $options = corporate_education_pro_get_theme_options();
        ?>
        <section id="counter" class="page-section col-4">
            <div class="white-shape top move-up left"></div>
            <div class="white-shape bottom move-down right"></div>

            <div class="wrapper">
                <?php for ( $i = 1; $i <= 4; $i++ ) :
                    $icon   = ! empty( $options['counter_icon_' . $i] ) ? $options['counter_icon_' . $i] : 'fa-tint';
                    $value  = ! empty( $options['counter_count_' . $i] ) ? $options['counter_count_' . $i] : '';
                    $title  = ! empty( $options['counter_title_' . $i] ) ? $options['counter_title_' . $i] : '';
                    if ( ! empty( $value ) && ! empty( $title ) ) :
                    ?>
                        <div class="hentry">
                            <div class="statwrap">
                                <i class="fa <?php echo esc_attr( $icon ); ?>"></i>
                                <span class="stat-count"><?php echo absint( $value ); ?></span>
                                <small><?php echo esc_html( $title ); ?></small>
                            </div><!-- .statwrap -->
                        </div><!-- .hentry -->
                    <?php endif;
                endfor; ?>
            </div><!-- .wrapper -->
        </section><!-- #counter -->
    <?php }
endif;
